@@ -5,10 +5,7 @@ Auto-generates TypeScript and Python WebSocket clients from RPC server handlers.
 """
 
 from .discovery import discover_rpc_methods
-from .type_converter import pydantic_to_typescript, pydantic_to_python
 
 __all__ = [
     'discover_rpc_methods',
-    'pydantic_to_typescript',
-    'pydantic_to_python',
 ]
